@@ -1,23 +1,7 @@
 /*
-  Copyright (c) 2015 Sandro Knauß <knauss@kolabsys.com>
+  SPDX-FileCopyrightText: 2015 Sandro Knauß <knauss@kolabsys.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "tagcache.h"
@@ -74,7 +58,7 @@ void TagCache::onTagRemoved(const Akonadi::Tag &tag)
 
 void TagCache::retrieveTags()
 {
-    Akonadi::TagFetchJob *tagFetchJob = new Akonadi::TagFetchJob(this);
+    auto *tagFetchJob = new Akonadi::TagFetchJob(this);
     tagFetchJob->fetchScope().fetchAttribute<Akonadi::TagAttribute>();
     connect(tagFetchJob, &Akonadi::TagFetchJob::result, this, &TagCache::onTagsFetched);
 }
@@ -85,7 +69,7 @@ void TagCache::onTagsFetched(KJob *job)
         qCWarning(CALENDARSUPPORT_LOG) << "Failed to fetch tags: " << job->errorString();
         return;
     }
-    Akonadi::TagFetchJob *fetchJob = static_cast<Akonadi::TagFetchJob *>(job);
+    auto *fetchJob = static_cast<Akonadi::TagFetchJob *>(job);
     const Akonadi::Tag::List lst = fetchJob->tags();
     for (const Akonadi::Tag &tag : lst) {
         onTagAdded(tag);
